@@ -21,6 +21,12 @@ class _AuditConformDumper(Dumper):
                      dict_location=self.URL % "8b46f31")
 
 
+class _ExptlDumper(Dumper):
+    def dump(self, system, writer):
+        with writer.category("_exptl") as lp:
+            lp.write(entry_id=system.id, method='THEORETICAL MODEL')
+
+
 class _DatabaseDumper(Dumper):
     def dump(self, system, writer):
         if system.database:
@@ -350,8 +356,11 @@ class _AlignmentDumper(Dumper):
                  "alignment_length", "alignment_type",
                  "alignment_mode"]) as lp:
             for a in system.alignments:
-                align_len = max(len(s.gapped_sequence) for pair in a.pairs
-                                for s in (pair.template, pair.target))
+                if a.pairs:
+                    align_len = max(len(s.gapped_sequence) for pair in a.pairs
+                                    for s in (pair.template, pair.target))
+                else:
+                    align_len = None
                 lp.write(alignment_id=a._id, data_id=a._data_id,
                          software_group_id=a.software._group_id if a.software
                          else None,
@@ -542,7 +551,7 @@ class ModelCIFVariant(Variant):
        See :func:`write` and :class:`ihm.dumper.Variant`."""
     _dumpers = [
         ihm.dumper._EntryDumper,  # must be first
-        ihm.dumper._StructDumper, ihm.dumper._CommentDumper,
+        ihm.dumper._StructDumper, _ExptlDumper, ihm.dumper._CommentDumper,
         _AuditConformDumper, _DatabaseDumper, ihm.dumper._CitationDumper,
         ihm.dumper._SoftwareDumper, _SoftwareGroupDumper,
         ihm.dumper._AuditAuthorDumper,
